EmoticonRegex: Emoticon regex

View source: R/emoticons.R

EmoticonRegexR Documentation

Emoticon regex

Description

Builds emoticon regex

Usage

EmoticonRegex(emoticon.re, front, back)

Arguments

emoticon.re

Regular expressions for each emoticon.

front

Regular expression for symbols that can appear in front of the emoticon.

back

Regular expression for symbols that can appear behind the emoticon.

Value

A single regular expression for all emoticons.


M3SOulu/EmoticonFindeR documentation built on June 24, 2022, 4:56 p.m.