EmoticonsAndEmojis: Find emoticons and emojis

View source: R/emoticons.R

EmoticonsAndEmojisR Documentation

Find emoticons and emojis

Description

Find emoticons and emojis

Usage

EmoticonsAndEmojis(
  data,
  text.col = "text",
  cols = NULL,
  include.text = TRUE,
  funcs = list(emoticon = FindEmoticons, emoji = FindUnicodeEmojis, slack =
    FindSlackEmojis)
)

Arguments

data

Data.table of data to find emoticons and emojis in.

text.col

Name of the column containing the text.

cols

Columns from data to keep. If NULL, then uses the key of data.

include.text

If TRUE, includes the original text in the table.

funcs

List of functions to use for identifying emoticons and emojis.

Value

A data.table object with emoticons and emojis extracted from the text and subset of columns from data.


M3SOulu/EmoticonFindeR documentation built on June 24, 2022, 4:56 p.m.