FindRegex: Find regex

View source: R/emoticons.R

FindRegexR Documentation

Find regex

Description

Builds a data.table object from locations matching a set of regular expressions.

Usage

FindRegex(text, regex, include.text = TRUE)

Arguments

text

Text to find regular expressions in.

regex

The regular expressions.

include.text

If TRUE, includes the original text in the table.

Value

A data.table object with the result of the regex extracted and where it starts and ends in the original text.


M3SOulu/EmoticonFindeR documentation built on June 24, 2022, 4:56 p.m.