| EmoticonRegex | R Documentation |
Builds emoticon regex
EmoticonRegex(emoticon.re, front, back)
emoticon.re |
Regular expressions for each emoticon. |
front |
Regular expression for symbols that can appear in front of the emoticon. |
back |
Regular expression for symbols that can appear behind the emoticon. |
A single regular expression for all emoticons.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.