| EmoticonsAndEmojis | R Documentation |
Find emoticons and emojis
EmoticonsAndEmojis(
data,
text.col = "text",
cols = NULL,
include.text = TRUE,
funcs = list(emoticon = FindEmoticons, emoji = FindUnicodeEmojis, slack =
FindSlackEmojis)
)
data |
Data.table of data to find emoticons and emojis in. |
text.col |
Name of the column containing the text. |
cols |
Columns from data to keep. If NULL, then uses the key of data. |
include.text |
If TRUE, includes the original text in the table. |
funcs |
List of functions to use for identifying emoticons and emojis. |
A data.table object with emoticons and emojis extracted from the text and subset of columns from data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.