| FindRegex | R Documentation |
Builds a data.table object from locations matching a set of regular expressions.
FindRegex(text, regex, include.text = TRUE)
text |
Text to find regular expressions in. |
regex |
The regular expressions. |
include.text |
If TRUE, includes the original text in the table. |
A data.table object with the result of the regex extracted and where it starts and ends in the original text.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.